==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fhancock0.9.tar.gz: hancock/setup.php <==
<?php

/*
	I'm aware that this plugin doesn't follow the guidelines imposed by the SquirrelMail gods. I don't like 80char wrap; I don't like spaces instead of tabs; etc. I have good reasons for my preferences. If you'd like to hear my rationale, by all means email. I promise I've thought it out very carefully.

joshua@medicalhost.com 
www.tty1.org/~joshua/
v.9 - 9 April 2003

*/

function squirrelmail_plugin_init_hancock () {
	global $squirrelmail_plugin_hooks;

	$squirrelmail_plugin_hooks['compose_send']['hancock'] = 'hancock_append_sig';
/*
	#$squirrelmail_plugin_hooks['loading_prefs']['hancock'] = 'hancock_load_prefs';
	#$squirrelmail_plugin_hooks['options_personal_save']['hancock'] = 'hancock_prefs_save';
	#$squirrelmail_plugin_hooks['options_personal_inside']['hancock'] = 'hancock_prefs_inside';
*/
	$squirrelmail_plugin_hooks["optpage_register_block"]['hancock'] =
                              'hancock_register_block';
}

function hancock_register_block(){
    global $optpage_blocks;
    
    $optpage_blocks[] = array(
        'name' => _("J. Hancock"),
        'url' => "../plugins/hancock/hancock_opt.php",
        'desc' => _("Set up random email signatures."),
        'js'   => false
    );
}

function hancock_append_sig() {
	//global $hancockEnabled, $hancockHeader, $hancockFooter, $hancockSigArray;
	global $body;
	
	$hancockEnabled = getPref($data_dir, $username, 'hancock_enabled');
	$hancockHeader = getPref($data_dir, $username, 'hancock_header');
	$hancockFooter = getPref($data_dir, $username, 'hancock_footer');
	$hancockSignatureStr = getPref($data_dir, $username, 'hancock_signatures');
	
	if (! $hancockEnabled ) { return ; } 
	
	$hancockSigArray = explode("!@#$%--!@#$%", $hancockSignatureStr);
	srand((double) microtime() * 1000000);
	$randomSigNum = rand(0, count($hancockSigArray)-1);
	$sig = implode("\r\n", explode("!@#$%", $hancockSigArray[$randomSigNum]));
	$theSig = "--\r\n";	
	if ($hancockHeader != '') { $theSig = $theSig . $hancockHeader . "\r\n"; }
	#$theSig = $theSig . $hancockSigArray[$randomSigNum];
	$theSig = $theSig . $sig;
	if ($hancockFooter != '') { $theSig = $theSig . "\r\n" . $hancockFooter ; }
	
	$body = $body . $theSig;
}

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fhancock-1.4-0.9.tar.gz: hancock/setup.php <==
<?php

/*
	I'm aware that this plugin doesn't follow the guidelines imposed by the SquirrelMail gods. I don't like 80char wrap; I don't like spaces instead of tabs; etc. I have good reasons for my preferences. Sorry.

*/

function squirrelmail_plugin_init_hancock () {
	global $squirrelmail_plugin_hooks;

	$squirrelmail_plugin_hooks['compose_send']['hancock'] = 'hancock_append_sig';
	$squirrelmail_plugin_hooks["optpage_register_block"]['hancock'] =
                              'hancock_register_block';
}

function hancock_register_block(){
    global $optpage_blocks;
    
    $optpage_blocks[] = array(
        'name' => _("J. Hancock"),
        'url' => "../plugins/hancock/hancock_opt.php",
        'desc' => _("Set up random email signatures."),
        'js'   => false
    );
}

function hancock_append_sig() {
	//global $hancockEnabled, $hancockHeader, $hancockFooter, $hancockSigArray;
	global $body;
	
	$hancockEnabled = getPref($data_dir, $username, 'hancock_enabled');
	$hancockHeader = getPref($data_dir, $username, 'hancock_header');
	$hancockFooter = getPref($data_dir, $username, 'hancock_footer');
	$hancockSignatureStr = getPref($data_dir, $username, 'hancock_signatures');
	
	if (! $hancockEnabled ) { return ; } 
	
	$hancockSigArray = explode("!@#$%--!@#$%", $hancockSignatureStr);
	srand((double) microtime() * 1000000);
	$randomSigNum = rand(0, count($hancockSigArray)-1);
	$sig = implode("\r\n", explode("!@#$%", $hancockSigArray[$randomSigNum]));
	$theSig = "--\r\n";	
	if ($hancockHeader != '') { $theSig = $theSig . $hancockHeader . "\r\n"; }
	#$theSig = $theSig . $hancockSigArray[$randomSigNum];
	$theSig = $theSig . $sig;
	if ($hancockFooter != '') { $theSig = $theSig . "\r\n" . $hancockFooter ; }
	
	$body = $body . $theSig;
}

?>
